@@ -8,14 +8,13 @@ main program executable
 import sys
 
 # additional libraries
-import merakitoolkit
-from merakitoolkitparser import parser
-
+from . import merakitoolkitparser # pylint: disable=import-error
+from . import merakitoolkit
 
 def main() -> int:
     '''merakitoolkit main program call'''
 
-    mainparser,return_code = parser()
+    mainparser,return_code = merakitoolkitparser.parser()
     if mainparser:
         if mainparser.command == "psk":
             merakiobj = merakitoolkit.MerakiToolkit(vars(mainparser))
